Learn R Programming

CTTinShiny (version 0.1.0)

shinyCTT: shinyCTT

Description

Launches the Shiny interface for CTT

Usage

shinyCTT()

Arguments

Value

No values are returned to R. After the Shiny interface launches all values are returned within the Shiny interface itself.

Details

Launches a Shiny interface that was developed in conjunction with the CTT package. The interface was designed to be intuitive and guide users through analyses. Some options are hidden until data are loaded. Also, some options (distractor analysis) are hidden unless raw data AND a key file are loaded.

Examples

Run this code
# NOT RUN {
shinyCTT()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab